==> latte-carousel-1.5.0.tgz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.5.0] - 2019-03-XX

### Added

-   Move count option
-   Default font size for latte-item children
-   Carousel move events
-   Drag free mode

### Changed

-   Updated dependencies

### Fixed

-   Optional configs

## [1.4.1] - 2018-11-01

### Fixed

-   Stage when carousel has fewer items than specified count from [@MatheusBordin](https://github.com/MatheusBordin).

## [1.4.0] - 2018-10-20

### Added

-   New carousel trigger events
-   Validation to avoid creating multiple instances using the same element

### Changed

-   Updated dependencies
-   Webpack CLI
-   Jest config to mock .scss imports

## [1.3.0] - 2018-10-10

### Added

-   Action to cancel tweens

### Changed

-   Updated dependencies

## [1.2.1] - 2018-08-18

### Added

-   CHANGELOG file
-   Setting for animation duration

### Changed

-   Updated dependencies

## [1.2.0] - 2018-08-12

### Fixed

-   TypeScript .d.ts generation

### Changed

-   Animation function

## [1.1.1] - 2018-08-11

### Changed

-   Package keywords

## [1.1.0] - 2018-08-01

### Fixed

-   Nested carousel
-   Carousel cleanup

## [1.0.3] - 2018-07-15

### Changed

-   Carousel creation with element or selector

## [1.0.2] - 2018-07-14

### Changed

-   README file with CDN links and centered logo

## [1.0.1] - 2018-07-09

### Added

-   Unit tests

### Changed

-   Updated dependencies

## [1.0.0] - 2018-07-05

### Added

-   Touch scroll lock

### Changed

-   Updated dependencies

## [0.9.0] - 2018-06-23

### Changed

-   Simplified HTML structure
-   Webpack build

### Fixed

-   Linters

## [0.7.0] - 2018-06-02

### Added

-   Travis CI
-   Issue templates
-   Pagination dots
-   Autoplay

### Fixed

-   Copy global options to responsive options from [@chrsmutti](https://github.com/chrsmutti).

## [0.5.0] - 2018-03-18

### Added

-   Basic carousel support
-   Build tasks

[unreleased]: https://github.com/latte-carousel/latte-carousel/compare/v1.4.1...develop
[1.4.1]: https://github.com/latte-carousel/latte-carousel/compare/v1.4.0...v1.4.1
[1.4.0]: https://github.com/latte-carousel/latte-carousel/compare/v1.3.0...v1.4.0
[1.3.0]: https://github.com/latte-carousel/latte-carousel/compare/v1.2.1...v1.3.0
[1.2.1]: https://github.com/latte-carousel/latte-carousel/compare/v1.2.0...v1.2.1
[1.2.0]: https://github.com/latte-carousel/latte-carousel/compare/v1.1.1...v1.2.0
[1.1.1]: https://github.com/latte-carousel/latte-carousel/compare/v1.1.0...v1.1.1
[1.1.0]: https://github.com/latte-carousel/latte-carousel/compare/v1.0.3...v1.1.0
[1.0.3]: https://github.com/latte-carousel/latte-carousel/compare/v1.0.2...v1.0.3
[1.0.2]: https://github.com/latte-carousel/latte-carousel/compare/v1.0.1...v1.0.2
[1.0.1]: https://github.com/latte-carousel/latte-carousel/compare/v1.0.0...v1.0.1
[1.0.0]: https://github.com/latte-carousel/latte-carousel/compare/0.9.0...v1.0.0
[0.9.0]: https://github.com/latte-carousel/latte-carousel/compare/0.7.0...0.9.0
[0.7.0]: https://github.com/latte-carousel/latte-carousel/compare/0.5.0...0.7.0
[0.5.0]: https://github.com/latte-carousel/latte-carousel/compare/013746bd4798255465ad248a3423a6fe80d9dab3...0.5.0

==> latte-carousel-1.5.1.tgz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.5.1] - 2019-03-20

### Added

-   Options documentation

### Fixed

-   Carousel options interface

## [1.5.0] - 2019-03-19

### Added

-   Move count option
-   Default font size for latte-item children
-   Carousel move events
-   Drag free mode

### Changed

-   Updated dependencies

### Fixed

-   Optional configs

## [1.4.1] - 2018-11-01

### Fixed

-   Stage when carousel has fewer items than specified count from [@MatheusBordin](https://github.com/MatheusBordin).

## [1.4.0] - 2018-10-20

### Added

-   New carousel trigger events
-   Validation to avoid creating multiple instances using the same element

### Changed

-   Updated dependencies
-   Webpack CLI
-   Jest config to mock .scss imports

## [1.3.0] - 2018-10-10

### Added

-   Action to cancel tweens

### Changed

-   Updated dependencies

## [1.2.1] - 2018-08-18

### Added

-   CHANGELOG file
-   Setting for animation duration

### Changed

-   Updated dependencies

## [1.2.0] - 2018-08-12

### Fixed

-   TypeScript .d.ts generation

### Changed

-   Animation function

## [1.1.1] - 2018-08-11

### Changed

-   Package keywords

## [1.1.0] - 2018-08-01

### Fixed

-   Nested carousel
-   Carousel cleanup

## [1.0.3] - 2018-07-15

### Changed

-   Carousel creation with element or selector

## [1.0.2] - 2018-07-14

### Changed

-   README file with CDN links and centered logo

## [1.0.1] - 2018-07-09

### Added

-   Unit tests

### Changed

-   Updated dependencies

## [1.0.0] - 2018-07-05

### Added

-   Touch scroll lock

### Changed

-   Updated dependencies

## [0.9.0] - 2018-06-23

### Changed

-   Simplified HTML structure
-   Webpack build

### Fixed

-   Linters

## [0.7.0] - 2018-06-02

### Added

-   Travis CI
-   Issue templates
-   Pagination dots
-   Autoplay

### Fixed

-   Copy global options to responsive options from [@chrsmutti](https://github.com/chrsmutti).

## [0.5.0] - 2018-03-18

### Added

-   Basic carousel support
-   Build tasks

[unreleased]: https://github.com/latte-carousel/latte-carousel/compare/master...develop
[1.5.1]: https://github.com/latte-carousel/latte-carousel/compare/v1.5.0...v1.5.1
[1.5.0]: https://github.com/latte-carousel/latte-carousel/compare/v1.4.1...v1.5.0
[1.4.1]: https://github.com/latte-carousel/latte-carousel/compare/v1.4.0...v1.4.1
[1.4.0]: https://github.com/latte-carousel/latte-carousel/compare/v1.3.0...v1.4.0
[1.3.0]: https://github.com/latte-carousel/latte-carousel/compare/v1.2.1...v1.3.0
[1.2.1]: https://github.com/latte-carousel/latte-carousel/compare/v1.2.0...v1.2.1
[1.2.0]: https://github.com/latte-carousel/latte-carousel/compare/v1.1.1...v1.2.0
[1.1.1]: https://github.com/latte-carousel/latte-carousel/compare/v1.1.0...v1.1.1
[1.1.0]: https://github.com/latte-carousel/latte-carousel/compare/v1.0.3...v1.1.0
[1.0.3]: https://github.com/latte-carousel/latte-carousel/compare/v1.0.2...v1.0.3
[1.0.2]: https://github.com/latte-carousel/latte-carousel/compare/v1.0.1...v1.0.2
[1.0.1]: https://github.com/latte-carousel/latte-carousel/compare/v1.0.0...v1.0.1
[1.0.0]: https://github.com/latte-carousel/latte-carousel/compare/0.9.0...v1.0.0
[0.9.0]: https://github.com/latte-carousel/latte-carousel/compare/0.7.0...0.9.0
[0.7.0]: https://github.com/latte-carousel/latte-carousel/compare/0.5.0...0.7.0
[0.5.0]: https://github.com/latte-carousel/latte-carousel/compare/013746bd4798255465ad248a3423a6fe80d9dab3...0.5.0
